"""Apprise target sink class, which handles writing streams."""
from singer_sdk.sinks import RecordSink
from typing import Optional
import apprise


class AppriseSink(RecordSink):
    """Apprise target sink class."""

    def process_record(self, record: dict, context: dict) -> None:
        """Process the record."""
        a = apprise.Apprise()
        for uri in self.config["uris"]:
            a.add(uri)

        title: Optional[str] = record.get("title")
        body: Optional[str] = record.get("body")
        if title is None and body is None:
            raise Exception("Both the title and body cannot be None")
        a.notify(title=title, body=body)



"""Apprise target class."""

from singer_sdk.target_base import Target
from singer_sdk import typing as th

from target_apprise.sinks import (
    AppriseSink,
)


class TargetApprise(Target):
    """Sample target for Apprise."""

    name = "target-apprise"
    config_jsonschema = th.PropertiesList(
        th.Property(
            "uris",
            th.ArrayType(th.StringType),
            description="Array of apprise URIs,"
            + "checkout https://github.com/caronc/apprise",
            required=True,
        ),
    ).to_dict()
    default_sink_class = AppriseSink



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['target_apprise', 'target_apprise.tests']

package_data = \
{'': ['*']}

install_requires = \
['apprise==1.2.0', 'requests>=2.25.1,<3.0.0', 'singer-sdk>=0.4.5,<0.5.0']

entry_points = \
{'console_scripts': ['target-apprise = '
                     'target_apprise.target:TargetApprise.cli']}

setup_kwargs = {
    'name': 'target-apprise',
    'version': '0.0.2',
    'description': '`target-apprise` is a Singer target for Apprise, built with the Meltano SDK for Singer Targets.',
    'long_description': None,
    'author': 'AutoIDM',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7.1,<3.11',
}


setup(**setup_kwargs)
